==> jc-1.4.0.tar.gz: javax/swing/plaf/ColorChooserUI.h <==
// public abstract class javax.swing.plaf.ColorChooserUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f865874bcf120fc4 javax_swing_plaf_ColorChooserUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ColorChooserUI_H_
#define _JC_javax_swing_plaf_ColorChooserUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ColorChooserUI$sub_refs	_jc_javax_swing_plaf_ColorChooserUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs	_jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$refs	_jc_javax_swing_plaf_ColorChooserUI$refs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$nonrefs	_jc_javax_swing_plaf_ColorChooserUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$object	_jc_javax_swing_plaf_ColorChooserUI$object;

typedef const struct _jc_javax_swing_plaf_ColorChooserUI$vmethods	_jc_javax_swing_plaf_ColorChooserUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ColorChooserUI$vtable	_jc_javax_swing_plaf_ColorChooserUI$vtable;
typedef const struct _jc_javax_swing_plaf_ColorChooserUI$vtype	_jc_javax_swing_plaf_ColorChooserUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ColorChooserUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ColorChooserUI$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_ColorChooserUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ColorChooserUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ColorChooserUI$vmethods	javax_swing_plaf_ColorChooserUI;
};

// Vtype
struct _jc_javax_swing_plaf_ColorChooserUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ColorChooserUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorChooserUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ColorChooserUI$refs {
    _jc_javax_swing_plaf_ColorChooserUI$sub_refs	javax_swing_plaf_ColorChooserUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ColorChooserUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs	javax_swing_plaf_ColorChooserUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ColorChooserUI$object {
	_jc_javax_swing_plaf_ColorChooserUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ColorChooserUI$vtype	*vtype;
	_jc_javax_swing_plaf_ColorChooserUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ColorChooserUI$vtype _jc_javax_swing_plaf_ColorChooserUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ColorChooserUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ColorChooserUI$class_object;

#endif	/* _JC_javax_swing_plaf_ColorChooserUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/ColorChooserUI.h <==
// public abstract class javax.swing.plaf.ColorChooserUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f865874bcf120fc4 javax_swing_plaf_ColorChooserUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ColorChooserUI_H_
#define _JC_javax_swing_plaf_ColorChooserUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ColorChooserUI$sub_refs	_jc_javax_swing_plaf_ColorChooserUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs	_jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$refs	_jc_javax_swing_plaf_ColorChooserUI$refs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$nonrefs	_jc_javax_swing_plaf_ColorChooserUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ColorChooserUI$object	_jc_javax_swing_plaf_ColorChooserUI$object;

typedef const struct _jc_javax_swing_plaf_ColorChooserUI$vmethods	_jc_javax_swing_plaf_ColorChooserUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ColorChooserUI$vtable	_jc_javax_swing_plaf_ColorChooserUI$vtable;
typedef const struct _jc_javax_swing_plaf_ColorChooserUI$vtype	_jc_javax_swing_plaf_ColorChooserUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ColorChooserUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ColorChooserUI$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_ColorChooserUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ColorChooserUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ColorChooserUI$vmethods	javax_swing_plaf_ColorChooserUI;
};

// Vtype
struct _jc_javax_swing_plaf_ColorChooserUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ColorChooserUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorChooserUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ColorChooserUI$refs {
    _jc_javax_swing_plaf_ColorChooserUI$sub_refs	javax_swing_plaf_ColorChooserUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ColorChooserUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ColorChooserUI$sub_nonrefs	javax_swing_plaf_ColorChooserUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ColorChooserUI$object {
	_jc_javax_swing_plaf_ColorChooserUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ColorChooserUI$vtype	*vtype;
	_jc_javax_swing_plaf_ColorChooserUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ColorChooserUI$vtype _jc_javax_swing_plaf_ColorChooserUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ColorChooserUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ColorChooserUI$class_object;

#endif	/* _JC_javax_swing_plaf_ColorChooserUI_H_ */
